import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk._jsii
import aws_cdk.aws_apigatewayv2_alpha._jsii
import aws_cdk.aws_apigatewayv2_authorizers_alpha._jsii
import aws_cdk.aws_apigatewayv2_integrations_alpha._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@pwrdrvr/microapps-cdk",
    "0.3.0-alpha.3",
    __name__[0:-6],
    "microapps-cdk@0.3.0-alpha.3.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
